==> mingw-w64-clang-aarch64-flecs-docs-4.0.1-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__cpp__addons__doc.js <==
var group__cpp__addons__doc =
[
    [ "flecs::doc::Description", "group__cpp__addons__doc.html#gad0795b4455fcad1eb215090c2b0dbe7e", null ],
    [ "flecs::entity_view::doc_brief", "group__cpp__addons__doc.html#gabf672e81afeddec4a4e2c0f8250ff021", null ],
    [ "flecs::entity_view::doc_color", "group__cpp__addons__doc.html#gac9ee07df2042efd85259a7cf2c4e55f6", null ],
    [ "flecs::entity_view::doc_detail", "group__cpp__addons__doc.html#gaad57d5f8523631450f0e3ea083fb0d35", null ],
    [ "flecs::entity_view::doc_link", "group__cpp__addons__doc.html#gaa537a0f49dbd7c563900f2480f85d6a0", null ],
    [ "flecs::entity_view::doc_name", "group__cpp__addons__doc.html#ga53dd532bce312cc69414e44c4cb9f938", null ],
    [ "flecs::doc::get_brief", "group__cpp__addons__doc.html#ga660e0a96fbc02c7bcec0fa78d680e3e4", null ],
    [ "flecs::doc::get_color", "group__cpp__addons__doc.html#ga054b1c1792d0965fed6272e409d3bd28", null ],
    [ "flecs::doc::get_detail", "group__cpp__addons__doc.html#ga6be5f8303fd180a587d67d7f01fb44a1", null ],
    [ "flecs::doc::get_link", "group__cpp__addons__doc.html#ga86918c97a1d4617dd43f48d4e966641d", null ],
    [ "flecs::doc::get_name", "group__cpp__addons__doc.html#gacad4321b9d85f19d5f9dc284680d1f1b", null ],
    [ "flecs::doc::set_brief", "group__cpp__addons__doc.html#ga74f596ae15851fab025e23b536afcccd", null ],
    [ "flecs::doc::set_color", "group__cpp__addons__doc.html#gacfbdf4129637148d387181d4057fcdf1", null ],
    [ "flecs::doc::set_detail", "group__cpp__addons__doc.html#gaefc4a467c2b02f850effcef835d094c5", null ],
    [ "flecs::entity_builder::set_doc_brief", "group__cpp__addons__doc.html#ga8f84eea617a139d8a7a6cc52039d4078", null ],
    [ "flecs::entity_builder::set_doc_color", "group__cpp__addons__doc.html#ga2d60291fe3b32d77299dbe2218f790a2", null ],
    [ "flecs::entity_builder::set_doc_detail", "group__cpp__addons__doc.html#gaffb31d7837dfc1c4dc3bae89659968d7", null ],
    [ "flecs::entity_builder::set_doc_link", "group__cpp__addons__doc.html#ga9898033ab60172b2ed5b675b99b96426", null ],
    [ "flecs::entity_builder::set_doc_name", "group__cpp__addons__doc.html#ga5820cd2803f99cc6ef41e1e5c0eec6a8", null ],
    [ "flecs::doc::set_link", "group__cpp__addons__doc.html#ga344d034ba4cad510bcd5dcb682a32df5", null ],
    [ "flecs::doc::set_name", "group__cpp__addons__doc.html#ga4e46731c6716724a3c1450413d7ff8a3", null ]
];

==> mingw-w64-clang-aarch64-flecs-docs-4.0.4-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__cpp__addons__doc.js <==
var group__cpp__addons__doc =
[
    [ "flecs::doc::Description", "group__cpp__addons__doc.html#gad0795b4455fcad1eb215090c2b0dbe7e", null ],
    [ "flecs::entity_view::doc_brief", "group__cpp__addons__doc.html#gabf672e81afeddec4a4e2c0f8250ff021", null ],
    [ "flecs::entity_view::doc_color", "group__cpp__addons__doc.html#gac9ee07df2042efd85259a7cf2c4e55f6", null ],
    [ "flecs::entity_view::doc_detail", "group__cpp__addons__doc.html#gaad57d5f8523631450f0e3ea083fb0d35", null ],
    [ "flecs::entity_view::doc_link", "group__cpp__addons__doc.html#gaa537a0f49dbd7c563900f2480f85d6a0", null ],
    [ "flecs::entity_view::doc_name", "group__cpp__addons__doc.html#ga53dd532bce312cc69414e44c4cb9f938", null ],
    [ "flecs::entity_view::doc_uuid", "group__cpp__addons__doc.html#gaa9f623f19cb2338d558dc5270fc4926e", null ],
    [ "flecs::doc::get_brief", "group__cpp__addons__doc.html#ga660e0a96fbc02c7bcec0fa78d680e3e4", null ],
    [ "flecs::doc::get_color", "group__cpp__addons__doc.html#ga054b1c1792d0965fed6272e409d3bd28", null ],
    [ "flecs::doc::get_detail", "group__cpp__addons__doc.html#ga6be5f8303fd180a587d67d7f01fb44a1", null ],
    [ "flecs::doc::get_link", "group__cpp__addons__doc.html#ga86918c97a1d4617dd43f48d4e966641d", null ],
    [ "flecs::doc::get_name", "group__cpp__addons__doc.html#gacad4321b9d85f19d5f9dc284680d1f1b", null ],
    [ "flecs::doc::get_uuid", "group__cpp__addons__doc.html#gadfa18355f34e7b7163c9f4e33d8cd12d", null ],
    [ "flecs::doc::set_brief", "group__cpp__addons__doc.html#ga74f596ae15851fab025e23b536afcccd", null ],
    [ "flecs::doc::set_color", "group__cpp__addons__doc.html#gacfbdf4129637148d387181d4057fcdf1", null ],
    [ "flecs::doc::set_detail", "group__cpp__addons__doc.html#gaefc4a467c2b02f850effcef835d094c5", null ],
    [ "flecs::entity_builder::set_doc_brief", "group__cpp__addons__doc.html#ga8f84eea617a139d8a7a6cc52039d4078", null ],
    [ "flecs::entity_builder::set_doc_color", "group__cpp__addons__doc.html#ga9cd9ef24259a552322746a84bbbb9a3c", null ],
    [ "flecs::entity_builder::set_doc_detail", "group__cpp__addons__doc.html#gaffb31d7837dfc1c4dc3bae89659968d7", null ],
    [ "flecs::entity_builder::set_doc_link", "group__cpp__addons__doc.html#ga9898033ab60172b2ed5b675b99b96426", null ],
    [ "flecs::entity_builder::set_doc_name", "group__cpp__addons__doc.html#ga5820cd2803f99cc6ef41e1e5c0eec6a8", null ],
    [ "flecs::entity_builder::set_doc_uuid", "group__cpp__addons__doc.html#ga1f1be3c70cc2b1174a843ab35da5cf66", null ],
    [ "flecs::doc::set_link", "group__cpp__addons__doc.html#ga344d034ba4cad510bcd5dcb682a32df5", null ],
    [ "flecs::doc::set_name", "group__cpp__addons__doc.html#ga4e46731c6716724a3c1450413d7ff8a3", null ],
    [ "flecs::doc::set_uuid", "group__cpp__addons__doc.html#ga2822aebdcb424f3548ea34708285e1f0", null ]
];
